@@ -17,8 +17,9 @@ class BlobManager(ManagedAuthentication):
         resource_group: str = None,
         account_name: str = None,
         account_key: str = None,
-        conn_str: str = os.getenv('BLOB_CONNECTION', None),
+        conn_str: str = None,
     ):  
+        conn_str = os.getenv('BLOB_CONNECTION', None)
         if account_name and account_key:
             self.service_client = BlobManager.auth(account_name, account_key)
             self.account_name = account_name
@@ -27,7 +28,6 @@ class BlobManager(ManagedAuthentication):
             self.service_client = BlobServiceClient.from_connection_string(
                 conn_str
             )
-
         else:
             resource_group_name = resource_group
             self.url = f"https://{account_name}.blob.core.windows.net"
@@ -53,9 +53,12 @@ class BlobManager(ManagedAuthentication):
                 print(good(f'Selecting I/O storage account ({account_name}).'))
             
             account_key = self._client.storage_accounts.list_keys(resource_group_name, account_name).keys[0].value
-
             self.account_name = account_name
             self.account_key = account_key
+            self.service_client = self.auth(
+                self.account_name,
+                self.account_key
+            )
 
     @staticmethod
     def auth(account_name: str, account_key: str):
