@@ -187,7 +187,7 @@ class Acido(object):
             self.image_registry_password
         )
         self.instance_manager = im
-        self.blob_manager = BlobManager(resource_group=self.rg, account_name='acido', login=login)
+        self.blob_manager = BlobManager(resource_group=self.rg, account_name='acido')
         self.blob_manager.use_container(container_name='acido', create_if_not_exists=True)
         self.all_instances, self.instances_named = self.ls(interactive=False)
 
@@ -271,7 +271,12 @@ class Acido(object):
                     'RG': self.rg,
                     'IMAGE_REGISTRY_SERVER': self.image_registry_server,
                     'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
-                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
+                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password,
+                    'BLOB_CONNECTION': (
+                        "DefaultEndpointsProtocol=https;"
+                        f"AccountName={self.blob_manager.account_name};AccountKey={self.blob_manager.account_key};"
+                        "EndpointSuffix=core.windows.net"
+                    )
                 }
                 group_name = f'{fleet_name}-{cg_n+1:02d}'
                 if group_name not in response.keys():
@@ -287,7 +292,12 @@ class Acido(object):
                     'RG': self.rg,
                     'IMAGE_REGISTRY_SERVER': self.image_registry_server,
                     'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
-                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
+                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password,
+                    'BLOB_CONNECTION': (
+                        "DefaultEndpointsProtocol=https;"
+                        f"AccountName={self.blob_manager.account_name};AccountKey={self.blob_manager.account_key};"
+                        "EndpointSuffix=core.windows.net"
+                    )
             }
             response[fleet_name] = self.instance_manager.deploy(name=fleet_name, instance_number=instance_num, env_vars=env_vars)
         
